
"""dfasdfasdfasdfasdasdasdasdfasdfasdfsd
sadfsdafasdfasdf
sadfasdf"""


def print_l(abc):
	for each in abc:
		if isinstance (each,list):
			print_l(each)
		else: print(each)



"""dfefewfasef
safaseegeafae

efaeaesfe"""
